BASE_URL = "https://gatherer.wizards.com/"
CARD_URL = BASE_URL + "Pages/Card/"


SUPERTYPES = {"Basic", "Legendary", "Ongoing", "Snow", "World"}
